@@ -7,10 +7,12 @@ from .decorators import (
     role_authorization,
     scope_role_auth,
     keycloak_role_auth,
+    token_attribute_role_mapping_auth,
 )
 from .handler import (
     RestHandler,
     RestHandlerSetup,
+    KeycloakUsernameMixin,
     OpenIDLoginHandler,
 )
 from .server import RestServer
@@ -19,10 +21,12 @@ __all__ = [
     "RestServer",
     "RestHandlerSetup",
     "RestHandler",
+    "KeycloakUsernameMixin",
     "OpenIDLoginHandler",
     "authenticated",
     "catch_error",
     "role_authorization",
     "scope_role_auth",
     "keycloak_role_auth",
+    "token_attribute_role_mapping_auth",
 ]
